pub struct TychoRouterEncoderBuilder { /* private fields */ }Expand description
Builder pattern for constructing a TychoRouterEncoder with customizable options.
This struct allows setting a chain and strategy encoder before building the final encoder.
Implementations
Sourceimpl TychoRouterEncoderBuilder
impl TychoRouterEncoderBuilder
pub fn new() -> Self
pub fn chain(self, chain: Chain) -> Self
pub fn swap_encoder_registry( self, swap_encoder_registry: SwapEncoderRegistry, ) -> Self
Sourcepub fn router_address(self, router_address: Bytes) -> Self
pub fn router_address(self, router_address: Bytes) -> Self
Sets the router_address manually.
If it’s not set, the default router address will be used (config/router_addresses.json)
Sourcepub fn build(self) -> Result<Box<dyn TychoEncoder>, EncodingError>
pub fn build(self) -> Result<Box<dyn TychoEncoder>, EncodingError>
Builds the TychoRouterEncoder instance using the configured chain.
Returns an error if either the chain has not been set.