Module models

Module models 

Structs

ClientFeeParams
Client fee parameters passed to the router, matching the Solidity ClientFeeParams struct.
EncodedSolution
Represents a solution that has been encoded for execution.
EncodingContext
Necessary context for encoding a swap within a strategy.
PermitDetails
Details of a permit.
PermitSingle
Represents a single permit for permit2.
Solution
Represents a solution containing details describing an order, and instructions for filling the order.
Swap
Represents a swap operation to be performed on a pool.

Enums

Strategy
UserTransferType
Specifies the method for transferring user funds into Tycho execution.