pub enum UserTransferType {
TransferFromPermit2,
TransferFrom,
UseVaultsFunds,
}Expand description
Specifies the method for transferring user funds into Tycho execution.
Options:
-
TransferFromPermit2: Use Permit2 for token transfer.- You must manually approve the Permit2 contract and sign the permit object externally
(outside
tycho-execution).
- You must manually approve the Permit2 contract and sign the permit object externally
(outside
-
TransferFrom: Use standard ERC-20 approval andtransferFrom.- You must approve the Tycho Router contract to spend your tokens via standard
approve()calls.
- You must approve the Tycho Router contract to spend your tokens via standard
-
UseVaultsFunds: No transfer will be performed and the Vault’s funds will be used- Assumes the tokens are already present in the Tycho Router.
- The tokens must be deposited into the TychoRouter before performing the swap
Variants