pub struct ClientFeeParams { /* private fields */ }Expand description
Client fee parameters passed to the router, matching the Solidity ClientFeeParams struct.
The default value (all zeros) represents no fee. Clients are responsible for constructing
and signing this struct; tycho-execution does not use it internally.
Implementations
Sourceimpl ClientFeeParams
impl ClientFeeParams
Sourcepub fn new(
client_fee_receiver: Bytes,
client_signature: Bytes,
deadline: BigUint,
client_fee_bps: u16,
) -> Self
pub fn new( client_fee_receiver: Bytes, client_signature: Bytes, deadline: BigUint, client_fee_bps: u16, ) -> Self
Creates params that identify the client and charge a fee in basis points.
Sourcepub fn new_without_fee(
client_fee_receiver: Bytes,
client_signature: Bytes,
deadline: BigUint,
) -> Self
pub fn new_without_fee( client_fee_receiver: Bytes, client_signature: Bytes, deadline: BigUint, ) -> Self
Creates params that identify the client for router fee discounts without charging a fee.
pub fn with_max_client_contribution( self, max_client_contribution: BigUint, ) -> Self