pub struct EncodingContext {
pub router_address: Option<Bytes>,
pub group_token_in: Bytes,
pub group_token_out: Bytes,
}Expand description
Necessary context for encoding a swap within a strategy.
Fields
router_address: Address of the router contract to be used for the swaps. Zero address if solution does not require router address.group_token_in: Token to be used as the input for the group swap.group_token_out: Token to be used as the output for the group swap.
Fields
router_address: Option<Bytes>group_token_in: Bytesgroup_token_out: BytesTrait Implementations
Sourceimpl Clone for EncodingContext
impl Clone for EncodingContext
Sourcefn clone(&self) -> EncodingContext
fn clone(&self) -> EncodingContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for EncodingContext
impl RefUnwindSafe for EncodingContext
impl Send for EncodingContext
impl Sync for EncodingContext
impl Unpin for EncodingContext
impl UnsafeUnpin for EncodingContext
impl UnwindSafe for EncodingContext