pub struct Swap { /* private fields */ }Expand description
Represents a swap operation to be performed on a pool.
Implementations
Sourceimpl Swap
impl Swap
pub fn new<T: Into<ProtocolComponent>>( component: T, token_in: Token, token_out: Token, estimated_gas: BigUint, ) -> Self
Sourcepub fn with_split(self, split: f64) -> Self
pub fn with_split(self, split: f64) -> Self
Sets the split value (percentage of the amount to be swapped)
Sourcepub fn with_user_data(self, user_data: Bytes) -> Self
pub fn with_user_data(self, user_data: Bytes) -> Self
Sets the user data to be passed to encoding
Sourcepub fn with_protocol_state(self, protocol_state: Arc<dyn ProtocolSim>) -> Self
pub fn with_protocol_state(self, protocol_state: Arc<dyn ProtocolSim>) -> Self
Sets the protocol state used to perform the swap
Sourcepub fn with_estimated_amount_in(self, estimated_amount_in: BigUint) -> Self
pub fn with_estimated_amount_in(self, estimated_amount_in: BigUint) -> Self
Sets the estimated amount in for RFQ protocols
pub fn component(&self) -> &ProtocolComponent
pub fn token_in(&self) -> &Token
pub fn token_out(&self) -> &Token
pub fn split(&self) -> f64
pub fn user_data(&self) -> &Option<Bytes>
pub fn protocol_state(&self) -> &Option<Arc<dyn ProtocolSim>>
pub fn estimated_amount_in(&self) -> &Option<BigUint>
pub fn estimated_gas(&self) -> &BigUint